@@ -1,8 +1,12 @@
 package Cassandra::Client::Config;
+our $AUTHORITY = 'cpan:TVDW';
+$Cassandra::Client::Config::VERSION = '0.12';
 use 5.010;
 use strict;
 use warnings;
 
+use Ref::Util qw/is_plain_arrayref/;
+
 sub new {
     my ($class, $config)= @_;
 
@@ -28,7 +32,7 @@ sub new {
     }, $class;
 
     if (my $cp= $config->{contact_points}) {
-        if (ref($cp) eq 'ARRAY') {
+        if (is_plain_arrayref($cp)) {
             @{$self->{contact_points}=[]}= @$cp;
         } else { die "contact_points must be an arrayref"; }
     } else { die "contact_points not specified"; }
@@ -73,3 +77,28 @@ sub new {
 }
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Cassandra::Client::Config
+
+=head1 VERSION
+
+version 0.12
+
+=head1 AUTHOR
+
+Tom van der Woerdt <tvdw@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Tom van der Woerdt.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
