@@ -1,8 +1,7 @@
 package Cassandra::Client::NetworkStatus;
 our $AUTHORITY = 'cpan:TVDW';
-$Cassandra::Client::NetworkStatus::VERSION = '0.14_003'; # TRIAL
-
-$Cassandra::Client::NetworkStatus::VERSION = '0.14003';use 5.010;
+$Cassandra::Client::NetworkStatus::VERSION = '0.12';
+use 5.010;
 use strict;
 use warnings;
 
@@ -40,8 +39,6 @@ sub select_master {
     }
     push @{$self->{waiting_for_cb}}, $callback;
 
-    my $pool= $self->{pool}; # non-weak
-
     my $attempts= 0;
     whilst(
         sub { # condition
@@ -61,7 +58,7 @@ sub select_master {
                 },
                 sub {
                     my ($next)= @_;
-                    $pool->get_one_cb($next);
+                    $self->{pool}->get_one_cb($next);
                 },
                 sub {
                     my ($next, $connection)= @_;
@@ -169,7 +166,7 @@ Cassandra::Client::NetworkStatus
 
 =head1 VERSION
 
-version 0.14_003
+version 0.12
 
 =head1 AUTHOR
 
@@ -177,7 +174,7 @@ Tom van der Woerdt <tvdw@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Tom van der Woerdt.
+This software is copyright (c) 2017 by Tom van der Woerdt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
