@@ -1,4 +1,6 @@
 package Cassandra::Client::Policy::LoadBalancing::Default;
+our $AUTHORITY = 'cpan:TVDW';
+$Cassandra::Client::Policy::LoadBalancing::Default::VERSION = '0.12';
 use 5.010;
 use strict;
 use warnings;
@@ -83,3 +85,28 @@ sub known_node_count {
 }
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Cassandra::Client::Policy::LoadBalancing::Default
+
+=head1 VERSION
+
+version 0.12
+
+=head1 AUTHOR
+
+Tom van der Woerdt <tvdw@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Tom van der Woerdt.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
