@@ -1,8 +1,7 @@
 package Cassandra::Client::Policy::Queue::Default;
 our $AUTHORITY = 'cpan:TVDW';
-$Cassandra::Client::Policy::Queue::Default::VERSION = '0.14_003'; # TRIAL
-
-$Cassandra::Client::Policy::Queue::Default::VERSION = '0.14003';use 5.010;
+$Cassandra::Client::Policy::Queue::Default::VERSION = '0.12';
+use 5.010;
 use strict;
 use warnings;
 
@@ -49,7 +48,7 @@ Cassandra::Client::Policy::Queue::Default
 
 =head1 VERSION
 
-version 0.14_003
+version 0.12
 
 =head1 AUTHOR
 
@@ -57,7 +56,7 @@ Tom van der Woerdt <tvdw@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Tom van der Woerdt.
+This software is copyright (c) 2017 by Tom van der Woerdt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
