@@ -1,4 +1,6 @@
 package Cassandra::Client::Policy::Retry::Default;
+our $AUTHORITY = 'cpan:TVDW';
+$Cassandra::Client::Policy::Retry::Default::VERSION = '0.12';
 use 5.010;
 use strict;
 use warnings;
@@ -37,4 +39,36 @@ sub on_write_timeout {
     return rethrow;
 }
 
+sub on_request_error {
+    my ($self, $statement, $consistency_level, $error, $nr_retries)= @_;
+
+    return rethrow if $nr_retries;
+    return try_next_host;
+}
+
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Cassandra::Client::Policy::Retry::Default
+
+=head1 VERSION
+
+version 0.12
+
+=head1 AUTHOR
+
+Tom van der Woerdt <tvdw@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Tom van der Woerdt.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
