@@ -1,9 +1,11 @@
 package Cassandra::Client::Policy::Throttle::Adaptive;
-
+our $AUTHORITY = 'cpan:TVDW';
+$Cassandra::Client::Policy::Throttle::Adaptive::VERSION = '0.12';
 use 5.010;
 use strict;
 use warnings;
-use Time::HiRes ();
+use Time::HiRes qw/CLOCK_MONOTONIC/;
+use Ref::Util qw/is_blessed_ref/;
 
 sub new {
     my ($class, %args)= @_;
@@ -19,7 +21,7 @@ sub new {
 
 sub _process_window {
     my ($self)= @_;
-    my $now= Time::HiRes::time;
+    my $now= Time::HiRes::clock_gettime(CLOCK_MONOTONIC);
     while (@{$self->{window}} && $self->{window}[0][0] < $now) {
         my $entry= shift @{$self->{window}};
         $self->{window_total}--;
@@ -42,10 +44,35 @@ sub should_fail {
 sub count {
     my ($self, $error, $force_error)= @_;
     $self->{window_total}++;
-    my $success= !(ref($error) && $error->{is_timeout}) && !$force_error;
-    push @{$self->{window}}, [ Time::HiRes::time()+$self->{time}, $success ];
+    my $success= !(is_blessed_ref($error) && $error->{is_timeout}) && !$force_error;
+    push @{$self->{window}}, [ Time::HiRes::clock_gettime(CLOCK_MONOTONIC)+$self->{time}, $success ];
     $self->{window_success}++ if $success;
     return;
 }
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Cassandra::Client::Policy::Throttle::Adaptive
+
+=head1 VERSION
+
+version 0.12
+
+=head1 AUTHOR
+
+Tom van der Woerdt <tvdw@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Tom van der Woerdt.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
