@@ -1,4 +1,6 @@
 package Cassandra::Client::Pool;
+our $AUTHORITY = 'cpan:TVDW';
+$Cassandra::Client::Pool::VERSION = '0.12';
 use 5.010;
 use strict;
 use warnings;
@@ -228,8 +230,13 @@ sub spawn_new_connection {
                 if ($self->{count} && @$waiters) {
                     warn 'We have callbacks waiting for a connection while we\'re connected';
                 }
+
+                my $max_conn= $self->{max_connections};
+                my $known_node_count= $self->{policy}->known_node_count;
+                my $max_attempts = ($max_conn < $known_node_count ? $max_conn : $known_node_count) + 1;
+
                 for my $waiter (@$waiters) {
-                    if ($waiter->{attempts}++ || !%{$self->{connecting}}) {
+                    if ((++$waiter->{attempts}) >= $max_attempts || !%{$self->{connecting}}) {
                         $waiter->{callback}->("Failed to connect to server");
                     } else {
                         push @{$self->{wait_connect} ||= []}, $waiter;
@@ -275,3 +282,28 @@ sub on_removed_node {
 }
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Cassandra::Client::Pool
+
+=head1 VERSION
+
+version 0.12
+
+=head1 AUTHOR
+
+Tom van der Woerdt <tvdw@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Tom van der Woerdt.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
