@@ -1,25 +1,28 @@
 package Cassandra::Client::Util;
+our $AUTHORITY = 'cpan:TVDW';
+$Cassandra::Client::Util::VERSION = '0.12';
 use 5.010;
 use strict;
 use warnings;
 
 use Exporter 'import';
-our @EXPORT= ('series', 'parallel');
+our @EXPORT= ('series', 'parallel', 'whilst');
+
+use Sub::Current;
 
 sub series {
     my $list= shift;
     my $final= shift;
 
-    my $cb_sub; $cb_sub= sub {
+    (shift @$list)->(sub {
         my $next= shift @$list;
         if ($next && !$_[0]) {
-            $_[0]= $cb_sub;
+            splice @_, 0, 1, ROUTINE();
             goto &$next;
         }
 
         goto &$final;
-    };
-    (shift @$list)->($cb_sub);
+    });
 
     return;
 }
@@ -56,4 +59,41 @@ sub parallel {
     return;
 }
 
+sub whilst {
+    my ($condition, $iteratee, $callback)= @_;
+
+    (sub {
+        if (defined $_[0] || !($condition->())) {
+            goto &$callback;
+        }
+        splice @_, 0, 1, ROUTINE();
+        goto &$iteratee;
+    })->();
+}
+
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Cassandra::Client::Util
+
+=head1 VERSION
+
+version 0.12
+
+=head1 AUTHOR
+
+Tom van der Woerdt <tvdw@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Tom van der Woerdt.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
